package org.rcisoft.business.cmsbankcard.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;


import org.rcisoft.business.cmsbankcard.entity.CmsBankCard;
import org.rcisoft.business.cmsbankcard.service.CmsBankCardService;

import java.util.List;

/**
* Created by cy on 2024年6月4日 上午10:19:34.
*/
@RestController
@RequestMapping("/cmsbankcard")
public class CmsBankCardController extends CyPaginationController<CmsBankCard> {


    @Autowired
    private CmsBankCardService cmsBankCardServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:add')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-新增用户_银行卡账号中间表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value="添加用户_银行卡账号中间表", notes="添加用户_银行卡账号中间表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsBankCard cmsBankCard, BindingResult bindingResult) {
        CyPersistModel data = cmsBankCardServiceImpl.persist(cmsBankCard);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBankCard);
    }
    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:delete')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-删除用户_银行卡账号中间表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value="删除用户_银行卡账号中间表", notes="删除用户_银行卡账号中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,CmsBankCard cmsBankCard) {
        CyPersistModel data = cmsBankCardServiceImpl.remove(cmsBankCard);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:update')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-修改用户_银行卡账号中间表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value="修改用户_银行卡账号中间表", notes="修改用户_银行卡账号中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid CmsBankCard cmsBankCard, BindingResult bindingResult) {
        CyPersistModel data = cmsBankCardServiceImpl.merge(cmsBankCard);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBankCard);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:query')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-查询用户_银行卡账号中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询单一用户_银行卡账号中间表", notes="查询单一用户_银行卡账号中间表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        cmsBankCardServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:list')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-查询用户_银行卡账号中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="查询用户_银行卡账号中间表集合", notes="查询用户_银行卡账号中间表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(CmsBankCard cmsBankCard) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            cmsBankCardServiceImpl.findAll(cmsBankCard));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:bankCard:list')")
    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-查询用户_银行卡账号中间表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value="分页查询用户_银行卡账号中间表集合", notes="分页查询用户_银行卡账号中间表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(CmsBankCard cmsBankCard) {
        cmsBankCardServiceImpl.findAllByPagination(getPaginationUtility(), cmsBankCard);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-用户_银行卡账号中间表管理-查询用户_银行卡账号中间表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出用户_银行卡账号中间表信息", notes = "导出用户_银行卡账号中间表信息")
    @GetMapping(value = "/export")
    public void outCmsBankCard(HttpServletResponse response,CmsBankCard cmsBankCard,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="用户_银行卡账号中间表信息.xls";break;
            case "1": excelName="用户_银行卡账号中间表信息.xlsx";break;
            case "2": excelName="用户_银行卡账号中间表信息.csv";break;
        }
        List<CmsBankCard> cmsBankCardList = cmsBankCardServiceImpl.export(cmsBankCard);
        CyEpExcelUtil.exportExcel(cmsBankCardList, "用户_银行卡账号中间表信息", "用户_银行卡账号中间表信息", CmsBankCard.class, excelName, response);
    }
}
