package org.rcisoft.business.cmsbanner.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsbanner.entity.CmsBanner;
import org.rcisoft.business.cmsbanner.entity.CmsBannerDTO;
import org.rcisoft.business.cmsbanner.service.CmsBannerService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年3月30日 下午1:51:15.
 */
@RestController
@RequestMapping("/cmsbanner")
public class CmsBannerController extends CyPaginationController<CmsBanner> {


    @Autowired
    private CmsBannerService cmsBannerServiceImpl;


    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:delete')")
    @CyOpeLogAnno(title = "system-banner管理管理-删除banner管理", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除banner管理", notes = "删除banner管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId, CmsBanner cmsBanner) {
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.remove(cmsBanner);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:update')")
    @CyOpeLogAnno(title = "system-banner管理管理-修改banner管理", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改banner管理", notes = "修改banner管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid CmsBanner cmsBanner, BindingResult bindingResult) {
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.merge(cmsBanner);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBanner);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:query')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一banner管理", notes = "查询单一banner管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBannerServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:list')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询banner管理集合", notes = "查询banner管理集合")
    @GetMapping(value = "/queryCmsBanners")
    public CyResult queryCmsBanners(CmsBanner cmsBanner) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBannerServiceImpl.findAll(cmsBanner));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:banner:list')")
    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询banner管理集合", notes = "分页查询banner管理集合")
    @GetMapping(value = "/queryCmsBannerByPagination")
    public CyGridModel listByPagination(CmsBanner cmsBanner) {
        cmsBannerServiceImpl.findAllByPagination(getPaginationUtility(), cmsBanner);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-banner管理管理-查询banner管理", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出banner管理信息", notes = "导出banner管理信息")
    @GetMapping(value = "/export")
    public void outCmsBanner(HttpServletResponse response, CmsBanner cmsBanner, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "banner管理信息.xls";
                break;
            case "1":
                excelName = "banner管理信息.xlsx";
                break;
            case "2":
                excelName = "banner管理信息.csv";
                break;
        }
        List<CmsBanner> cmsBannerList = cmsBannerServiceImpl.export(cmsBanner);
        CyEpExcelUtil.exportExcel(cmsBannerList, "banner管理信息", "banner管理信息", CmsBanner.class, excelName, response);
    }
    /*-------------------------------------------------------通用-------------------------------------------------*/

    /**
     * 分页查询当前用户的banner的列表
     */
    @ApiOperation(value = "分页查询当前用户的banner的列表", notes = "分页查询当前用户的banner的列表")
    @GetMapping(value = "/queryCmsBannerByPaginationForWx")
    public CyResult listByPaginationForWx(CmsBannerDTO cmsBanner) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBannerServiceImpl.findAllByPaginationForWx(getPaginationUtility(), cmsBanner));
    }

    /*-------------------------------------------------------管理端-------------------------------------------------*/

    /**
     * banner添加
     */
    @CyOpeLogAnno(title = "system-banner管理管理-新增banner管理", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加banner管理", notes = "添加banner管理")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsBanner cmsBanner, BindingResult bindingResult) {
        CyPersistModel data = cmsBannerServiceImpl.persist(cmsBanner);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBanner);
    }

    /**
     * 根据id修改当前的banner信息
     */
    @ApiOperation(value = "根据id修改当前的banner信息", notes = "根据id修改当前的banner信息")
    @PutMapping(value = "/updateCmsBannerById")
    public CyResult updateCmsBannerById(@Valid CmsBanner cmsBanner) {
        return CyResultGenUtil.builder(cmsBannerServiceImpl.updateCmsBannerById(cmsBanner),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBanner);
    }

    /**
     * banner 逻辑删除
     */
    @CyOpeLogAnno(title = "system-banner管理管理-删除banner管理", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除banner管理", notes = "逻辑删除banner管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}/{unitId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId, @PathVariable String unitId, CmsBanner cmsBanner) {
        //unit 判null
        if (!"null".equals(unitId)) {
            cmsBanner.setUnitId(unitId);
        }
        cmsBanner.setBusinessId(Integer.valueOf(businessId));
        CyPersistModel data = cmsBannerServiceImpl.removeLogical(cmsBanner);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    /**
     * 超级管理员分配banner给商家
     */
    @ApiOperation(value = "超级管理员分配banner给商家", notes = "超级管理员分配banner给商家")
    @PostMapping(value = "/assignBannerToBusiness")
    public CyResult assignBannerToBusiness(@Valid CmsBanner cmsBanner) {
        return CyResultGenUtil.builder(cmsBannerServiceImpl.assignBannerToBusiness(cmsBanner),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsBanner);
    }


    /*------------------------------------------------------微信小程序----------------------------------------------*/


}
