package org.rcisoft.business.cmsbannerunit.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.cmsbannerunit.dao.CmsBannerUnitRepository;
import org.rcisoft.business.cmsbannerunit.entity.CmsBannerUnit;
import org.rcisoft.business.cmsbannerunit.service.CmsBannerUnitService;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年6月7日 下午2:29:37.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsBannerUnitServiceImpl extends ServiceImpl<CmsBannerUnitRepository, CmsBannerUnit> implements CmsBannerUnitService {


    /**
     * 保存 banner与商家中间表
     *
     * @param cmsBannerUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsBannerUnit cmsBannerUnit) {
        //增加操作
        int line = baseMapper.insert(cmsBannerUnit);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                cmsBannerUnit.getBusinessId() + "的banner与商家中间表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 banner与商家中间表
     *
     * @param cmsBannerUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsBannerUnit cmsBannerUnit) {
        int line = baseMapper.realDelete(cmsBannerUnit);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsBannerUnit.getBusinessId() + "的banner与商家中间表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 banner与商家中间表
     *
     * @param cmsBannerUnit
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsBannerUnit cmsBannerUnit) {
        int line = baseMapper.updateById(cmsBannerUnit);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsBannerUnit.getBusinessId() + "的banner与商家中间表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 banner与商家中间表
     *
     * @param id
     * @return
     */
    @Override
    public CmsBannerUnit findById(int id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 banner与商家中间表
     *
     * @param cmsBannerUnit
     * @return
     */
    @Override
    public IPage<CmsBannerUnit> findAllByPagination(CyPageInfo<CmsBannerUnit> paginationUtility,
                                                    CmsBannerUnit cmsBannerUnit) {
        return baseMapper.queryCmsBannerUnitsPaged(paginationUtility, cmsBannerUnit);

    }

    /**
     * 查询list banner与商家中间表
     *
     * @param cmsBannerUnit
     * @return
     */
    @Override
    public List<CmsBannerUnit> findAll(CmsBannerUnit cmsBannerUnit) {
        return baseMapper.queryCmsBannerUnits(cmsBannerUnit);

    }

    /**
     * 导出banner与商家中间表
     *
     * @return
     */
    @Override
    public List<CmsBannerUnit> export(CmsBannerUnit cmsBannerUnit) {
        List<CmsBannerUnit> cmsBannerUnitList = baseMapper.queryCmsBannerUnits(cmsBannerUnit);
        return cmsBannerUnitList;
    }

    @Override
    public void deleteTheUserByMerchantId(SysUnit sysUnit) {
        baseMapper.deleteTheUserByMerchantId(sysUnit);
    }

}
