package org.rcisoft.business.cmsnews.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.cmsnews.dao.CmsNewsRepository;
import org.rcisoft.business.cmsnews.dto.MiniCmsNewsOrVideo;
import org.rcisoft.business.cmsnews.entity.CmsNews;
import org.rcisoft.business.cmsnews.service.CmsNewsService;
import org.rcisoft.business.cmspriceclick.dao.CmsPriceClickRepository;
import org.rcisoft.business.cmsunitnewvideo.dao.CmsUnitNewVideoRepository;
import org.rcisoft.business.cmsunitnewvideo.entity.CmsUnitNewVideo;
import org.rcisoft.business.cmsvideo.dao.CmsVideoRepository;
import org.rcisoft.business.cmsvideo.entity.CmsVideo;
import org.rcisoft.business.ossinfo.dao.OssInfoRepository;
import org.rcisoft.business.ossinfo.entity.OssInfo;
import org.rcisoft.business.sysunit.dao.SysUnitRepository;
import org.rcisoft.business.sysunit.service.impl.SysUnitServiceImpl;
import org.rcisoft.common.component.Global;
import org.rcisoft.core.component.CyInitComp;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.result.ResultServiceEnums;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * Created by cy on 2024年6月3日 下午3:35:01.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsNewsServiceImpl extends ServiceImpl<CmsNewsRepository, CmsNews> implements CmsNewsService {

    @Autowired
    private Global global;

    @Autowired
    private CyInitComp cyInitComp;

    @Autowired
    private CmsUnitNewVideoRepository cmsUnitNewVideoRepository;

    @Autowired
    private OssInfoRepository ossInfoRepository;

    @Autowired
    private CmsVideoRepository cmsVideoRepository;
    @Autowired
    private SysUnitServiceImpl sysUnitServiceImpl;
    @Autowired
    private SysUnitRepository sysUnitRepository;
    @Autowired
    private CmsNewsRepository cmsNewsRepository;
    @Autowired
    private CmsPriceClickRepository cmsPriceClickRepository;


    /**
     * 保存 文章表
     *
     * @param cmsNews
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsNews cmsNews) {
        //增加操作
        //当图片字段没有时增加默认1
        if (ObjectUtil.isNull(cmsNews.getPictureId())) {
            cmsNews.setPictureId(global.getDEFAULT_NEWS_LOCATION());
        }
        CmsNews check = baseMapper.checkWeight(cmsNews.getWeight());
        if (ObjectUtil.isNotNull(check)) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            if (cmsNews.getDetails() != null) {
                //移除16进制表情
                cmsNews.setDetails(cmsNews.getDetails().replaceAll("[\uD83C-\uDBFF\uDC00-\uDFFF]", ""));
            }

            int line = baseMapper.insert(cmsNews);
            //判断如果当前用户为商家管理员 将这个与商家管理员进行绑定


            if (CyUserUtil.getAuthenRoleIds() != null && CyUserUtil.getAuthenRoleIds().equals(cyInitComp.unit[0])) {
                //创建绑定
                CmsUnitNewVideo cmsUnitNewVideo = new CmsUnitNewVideo();
                cmsUnitNewVideo.setNewsVideoId(cmsNews.getBusinessId());
                cmsUnitNewVideo.setUnitId(cmsNews.getUnitId());
                cmsUnitNewVideo.setType("0");
                cmsUnitNewVideoRepository.insert(cmsUnitNewVideo);
                //查询当前商家下的代言人
//                List<Integer> integers = sysUnitRepository.selectByUnitId(cmsNews.getUnitId());
                //创建文章视频推广
//                for (Integer integer : integers) {
//                    CmsPriceClick cmsPriceClick = new CmsPriceClick();
//                    cmsPriceClick.setType(cmsUnitNewVideo.getType());
//                    cmsPriceClick.setNewsVideoId(cmsUnitNewVideo.getNewsVideoId());
//                    cmsPriceClick.setUserId(integer);
//                    cmsPriceClick.setUnitId(Integer.valueOf(cmsNews.getUnitId()));
//                    cmsPriceClick.setPrice(BigDecimal.valueOf(0));
//                    cmsPriceClick.setDelFlag(String.valueOf(0));
//                    cmsPriceClick.setFlag(String.valueOf(1));
//                    cmsPriceClick.setClickThroughRate(0);
//                    cmsPriceClick.setCreateBy(CyUserUtil.getAuthenBusinessId());
//                    cmsPriceClick.setUpdateBy(CyUserUtil.getAuthenBusinessId());
//                    cmsPriceClick.setCreateDate(new Date());
//                    cmsPriceClick.setUpdateDate(new Date());
//                    cmsPriceClickRepository.insert(cmsPriceClick);
//                }


            }
            log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                    cmsNews.getBusinessId() + "的文章表信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 删除 文章表
     *
     * @param cmsNews
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsNews cmsNews) {
        int line = baseMapper.realDelete(cmsNews);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsNews.getBusinessId() + "的文章表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 文章表
     *
     * @param cmsNews
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsNews cmsNews) {
        //获得当前登录人角色
        String authenRoleIds = CyUserUtil.getAuthenRoleIds();
        //判断当前角色为?
        //1.超级管理员
        if (authenRoleIds.equals(cyInitComp.admin[0])) {
            //超级管理员点击删除当前文章后 清除当前文章与所有商家的关联关系,推广表中当前文章的所有信息
            //1.1物理删除当前文章
            cmsNews.setDeleted();
            int line = baseMapper.deleteById(cmsNews);
            //1.2 删除当前文章与所有商家的关联
            cmsUnitNewVideoRepository.deleteByNewsVideoId(cmsNews.getBusinessId(), "0");
            //1.3 逻辑删除当前推广表 推广表中当前文章的所有信息
            cmsPriceClickRepository.updateTheUserByNewVideoId(cmsNews.getBusinessId(), "0");
        }
        //2.商家管理员
        if (authenRoleIds.equals(cyInitComp.unit[0])) {
            //判断是否传入当前的商家id
            if (cmsNews.getUnitId() != null) {
                //商家管理员点击删除当前文章后 清除当前文章与商家的关联关系,推广表中当前文章的所有信息
                cmsUnitNewVideoRepository.deleteByUnitIdAndNewsVideoId(cmsNews.getUnitId(), cmsNews.getBusinessId(), "0");
                //逻辑删除当前推广表中的当前文章下当前商家的信息
                cmsPriceClickRepository.updateTheUserByNewVideoIdUnitId(cmsNews.getUnitId(), cmsNews.getBusinessId(), "0");

            }
            return new CyPersistModel(1);
        }
        return new CyPersistModel(1);
    }

    /**
     * 修改 文章表
     *
     * @param cmsNews
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsNews cmsNews) {
        //修改文本中的#image
        String details = cmsNews.getDetails().replace("#image", "data:image");
        cmsNews.setDetails(details);
        CmsNews check = baseMapper.checkWeight(cmsNews.getWeight());
        if (ObjectUtil.isNotNull(check) && !check.getBusinessId().equals(cmsNews.getBusinessId())) {
            throw new CyServiceException(500, "权重已存在");
        } else {
            cmsNews.setUpdateDate(new Date());
            int line = baseMapper.updateById(cmsNews);
            log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsNews.getBusinessId() + "的文章表信息");
            return new CyPersistModel(line);
        }
    }

    /**
     * 根据id查询 文章表
     *
     * @param id
     * @return
     */
    @Override
    public CmsNews findById(int id) {
        CmsNews cmsNews = baseMapper.selectById(id);
        if (cmsNews != null && StringUtils.isNotEmpty(cmsNews.getPictureId())) {
            OssInfo ossInfo = ossInfoRepository.selectById(cmsNews.getPictureId());
            if (ossInfo.getPath() != null) {
                cmsNews.setPath(global.getBase_Discovery() + ossInfo.getPath());
            }
        }
        return cmsNews;
    }

    /**
     * 分页查询 文章表
     *
     * @param cmsNews
     * @return
     */
    @Override
    public IPage<CmsNews> findAllByPagination(CyPageInfo<CmsNews> paginationUtility,
                                              CmsNews cmsNews) {
        //查询当前角色
        String role = CyUserUtil.getAuthenRoleIds();
        //第一个 为超级管理员
        if (StringUtils.isNotEmpty(role) && cyInitComp.admin[0].equals(role)) {
            //超级管理员查询所有并且带分页
            IPage<CmsNews> cmsNewsIPage = baseMapper.superAdminQueryCmsNewssPaged(paginationUtility, cmsNews);
            //配置图片头部路径
            cmsNewsIPage.getRecords().forEach(cmsNews1 -> {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            });
            return cmsNewsIPage;
        }
        //第二为商家管理员
        if (StringUtils.isNotEmpty(role) && cyInitComp.unit[0].equals(role)) {
            //商家管理员查询当前商家并且分页
            IPage<CmsNews> cmsNewsIPage = baseMapper.businessAdminsQueryCmsNewssPaged(paginationUtility, cmsNews);
            //配置图片头部路径
            cmsNewsIPage.getRecords().forEach(cmsNews1 -> {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            });
            return cmsNewsIPage;
        }

//        if (StringUtils.isNotEmpty(role) && cyInitComp.getPermission()[0].equals(role)) {
//            if (CyUserUtil.getAuthenBusinessId() != null) {
//                cmsNews.setTenant(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
//            }
//        }
//        IPage<CmsNews> cmsNewsIPage = baseMapper.queryCmsNewssPaged(paginationUtility, cmsNews);
//        List<CmsNews> records = cmsNewsIPage.getRecords();
//        //查询文章所属商家信息
//        LambdaQueryWrapper<CmsUnitNewVideo> qw = new LambdaQueryWrapper<>();
//        qw.eq(CmsUnitNewVideo::getType, "0");
//        List<CmsUnitNewVideo> cmsUnitNewVideos = cmsUnitNewVideoRepository.selectList(qw);
//        //根据文章id查询商家信息
//        Map<Integer, List<CmsUnitNewVideo>> map = cmsUnitNewVideos.stream().collect(Collectors.groupingBy(CmsUnitNewVideo::getNewsVideoId));
//        for (CmsNews cmsNews1 : records) {
//            if (map.containsKey(cmsNews1.getBusinessId()) && map.get(cmsNews1.getBusinessId()) != null) {
//                List<CmsUnitNewVideo> cmsUnitNewVideos1 = map.get(cmsNews1.getBusinessId());
//                List<String> deptIds = cmsUnitNewVideos1.stream().map(CmsUnitNewVideo::getUnitId).collect(Collectors.toList());
//                cmsNews1.setUnitId(deptIds.toString());
//            }
//            if (cmsNews1.getPath() != null) {
//                cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
//            }
//        }
//        return cmsNewsIPage;
        return null;
    }

    /**
     * 查询list 文章表
     *
     * @param cmsNews
     * @return
     */
    @Override
    public List<CmsNews> findAll(CmsNews cmsNews) {
        return baseMapper.queryCmsNewss(cmsNews);

    }

    /**
     * 导出文章表
     *
     * @return
     */
    @Override
    public List<CmsNews> export(CmsNews cmsNews) {
        List<CmsNews> cmsNewsList = baseMapper.queryCmsNewss(cmsNews);
        return cmsNewsList;
    }

    /**
     * 查询首页文章
     * 未登陆 查询推荐文章
     * 登陆 查询自己拥有的文章
     *
     * @param paginationUtility
     * @param cmsNews
     * @return
     */
    @Override
    public IPage<CmsNews> listMiniProgram(CyPageInfo<CmsNews> paginationUtility, CmsNews cmsNews) {
        //未登陆
        if (CyUserUtil.getAuthenUsername() == null) {
            IPage<CmsNews> cmsNewsIPage = baseMapper.noLoginlistTop(paginationUtility, cmsNews);
            List<CmsNews> records = cmsNewsIPage.getRecords();
            for (CmsNews cmsNews1 : records) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            }
            return cmsNewsIPage;
        }

        //登陆后会从 首页/分类我的中进入   1是首页  2是分类和我的
        if ("1".equals(cmsNews.getSource())) {
            //超级管理员
            if (CyUserUtil.getAuthenRoleIds().equals(cyInitComp.admin[0])) {
                //超级管理员
                IPage<CmsNews> cmsNewsIPage = baseMapper.listTopAdmin(paginationUtility, cmsNews);
                List<CmsNews> records = cmsNewsIPage.getRecords();
                for (CmsNews cmsNews1 : records) {
                    if (cmsNews1.getPath() != null) {
                        cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                    }
                }
                return cmsNewsIPage;
            }
            //当前商家下的文章以及设置为推荐文章
            IPage<CmsNews> cmsNewsIPage = baseMapper.listTopMerchants(paginationUtility, cmsNews);
            List<CmsNews> records = cmsNewsIPage.getRecords();
            for (CmsNews cmsNews1 : records) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            }
            return cmsNewsIPage;
        }

        return null;
    }

    @Override
    public HashMap<String, List<MiniCmsNewsOrVideo>> listByNewsAndVideo(CyPageInfo<CmsNews> paginationUtility, CmsNews cmsNews) {
        //校验是否登录
        if (CyUserUtil.getAuthenBusinessId() == null) {
            throw new CyServiceException(ResultServiceEnums.NOT_LOGIN.getCode(), ResultServiceEnums.NOT_LOGIN.getMessage());
        } else {
            cmsNews.setUserId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
        }
        //校验是否包含商家信息
        if (StringUtils.isEmpty(cmsNews.getUnitId())) {
            throw new CyServiceException(ResultServiceEnums.NOT_SELECT_UNIT.getCode(), ResultServiceEnums.NOT_SELECT_UNIT.getMessage());
        }
        HashMap<String, List<MiniCmsNewsOrVideo>> map = new HashMap<>();
        IPage<CmsNews> cmsNewsIPage = baseMapper.listByClassification(paginationUtility, cmsNews);
        List<CmsNews> newRecords = cmsNewsIPage.getRecords();
        List<MiniCmsNewsOrVideo> list = new ArrayList<>();
        for (CmsNews cmsNews1 : newRecords) {
            if (cmsNews1.getPath() != null) {
                cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
            }
            //数据封装
            MiniCmsNewsOrVideo miniCmsNewsOrVideo = new MiniCmsNewsOrVideo();
            BeanUtils.copyProperties(cmsNews1, miniCmsNewsOrVideo);
            list.add(miniCmsNewsOrVideo);
        }
        //文章 0
        map.put("0", list);
        //查询视频
        CmsVideo cmsVideo = new CmsVideo();
        cmsVideo.setUnitId(cmsNews.getUnitId());
        cmsVideo.setUserId(cmsNews.getUserId());
        ArrayList<MiniCmsNewsOrVideo> miniCmsNewsOrVideos = new ArrayList<>();
        List<CmsVideo> videos = cmsVideoRepository.listByClassification(cmsVideo);
        for (CmsVideo cmsVideo1 : videos) {
            if (cmsVideo1.getPath() != null) {
                cmsVideo1.setPath(global.getBase_Discovery() + cmsVideo1.getPath());
            }
            //数据封装
            MiniCmsNewsOrVideo miniCmsNewsOrVideo = new MiniCmsNewsOrVideo();
            BeanUtils.copyProperties(cmsVideo1, miniCmsNewsOrVideo);
            miniCmsNewsOrVideo.setTitle(cmsVideo1.getVideoTitle());
            miniCmsNewsOrVideos.add(miniCmsNewsOrVideo);
        }
        //视频 1
        map.put("1", miniCmsNewsOrVideos);
        return map;
    }

    @Override
    public IPage<CmsNews> listByClassification(CyPageInfo<CmsNews> paginationUtility, CmsNews cmsNews) {
        //校验是否登录
        if (CyUserUtil.getAuthenBusinessId() == null) {
            throw new CyServiceException(ResultServiceEnums.NOT_LOGIN.getCode(), ResultServiceEnums.NOT_LOGIN.getMessage());
        } else {
            cmsNews.setUserId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
        }
        //超级管理员
        if (CyUserUtil.getAuthenRoleIds().equals(cyInitComp.admin[0])) {
            //超级管理员
            IPage<CmsNews> cmsNewsIPage = baseMapper.listByClassificationAdmin(paginationUtility, cmsNews);
            List<CmsNews> records = cmsNewsIPage.getRecords();
            for (CmsNews cmsNews1 : records) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            }
            return cmsNewsIPage;
        }
        //商家管理员
        if (CyUserUtil.getAuthenRoleIds().equals(cyInitComp.unit[0])) {
            //商家管理员
            IPage<CmsNews> cmsNewsIPage = baseMapper.listByClassificationMerchants(paginationUtility, cmsNews);
            List<CmsNews> records = cmsNewsIPage.getRecords();
            for (CmsNews cmsNews1 : records) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
            }
            return cmsNewsIPage;
        }


        //校验是否包含商家信息
        if (StringUtils.isEmpty(cmsNews.getUnitId())) {
            throw new CyServiceException(ResultServiceEnums.NOT_SELECT_UNIT.getCode(), ResultServiceEnums.NOT_SELECT_UNIT.getMessage());
        }
        HashMap<String, List<MiniCmsNewsOrVideo>> map = new HashMap<>();
        IPage<CmsNews> cmsNewsIPage = baseMapper.listByClassification(paginationUtility, cmsNews);
        List<CmsNews> newRecords = cmsNewsIPage.getRecords();
        for (CmsNews cmsNews1 : newRecords) {
            if (cmsNews1.getPath() != null) {
                cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
            }
        }
        return cmsNewsIPage;
    }

    @Override
    public Integer selectDictionaryControl(String name, String hōtoriNum) {
        return baseMapper.selectDictionaryControl(name, hōtoriNum);
    }

    @Override
    public String getNewsByTitleByTitle(String title) {
        return baseMapper.getNewsByTitleByTitle(title);
    }

    @Override
    public IPage<CmsVideo> listByTopVideo(CyPageInfo<CmsNews> paginationUtility, CmsVideo cmsVideo) {
        //校验是否登录  //游客状态下
        if (CyUserUtil.getAuthenBusinessId() == null) {
            cmsVideo.setHomeDisplay("1");
            IPage<CmsVideo> cmsVideoIPage = baseMapper.listByTopVideo(paginationUtility, cmsVideo);
            List<CmsVideo> videoRecords = cmsVideoIPage.getRecords();
            for (CmsVideo cmsNews1 : videoRecords) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
                //封面
                if (cmsNews1.getDefaultUrl() != null) {
                    cmsNews1.setDefaultUrl(global.getBase_Discovery() + cmsNews1.getDefaultUrl());
                }
            }
            return cmsVideoIPage;
        }
        //超级管理员
        if (CyUserUtil.getAuthenRoleIds().equals(cyInitComp.admin[0])) {
            //超级管理员
            IPage<CmsVideo> cmsVideoIPage = baseMapper.listTopVideoAdmin(paginationUtility, cmsVideo);
            List<CmsVideo> videoRecords = cmsVideoIPage.getRecords();
            for (CmsVideo cmsNews1 : videoRecords) {
                if (cmsNews1.getPath() != null) {
                    cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
                }
                //封面
                if (cmsNews1.getDefaultUrl() != null) {
                    cmsNews1.setDefaultUrl(global.getBase_Discovery() + cmsNews1.getDefaultUrl());
                }
            }
            return cmsVideoIPage;
        }


        //登陆后
        cmsVideo.setUserId(Integer.valueOf(CyUserUtil.getAuthenBusinessId()));
        //校验是否包含商家信息
        if (StringUtils.isEmpty(cmsVideo.getUnitId())) {
            cmsVideo.setHomeDisplay("1");
        }
        IPage<CmsVideo> cmsVideoIPage = baseMapper.listByTopVideoHome(paginationUtility, cmsVideo);
        List<CmsVideo> videoRecords = cmsVideoIPage.getRecords();
        for (CmsVideo cmsNews1 : videoRecords) {
            if (cmsNews1.getPath() != null) {
                cmsNews1.setPath(global.getBase_Discovery() + cmsNews1.getPath());
            }
            //封面
            if (cmsNews1.getDefaultUrl() != null) {
                cmsNews1.setDefaultUrl(global.getBase_Discovery() + cmsNews1.getDefaultUrl());
            }
        }
        return cmsVideoIPage;
    }

    @Override
    public CyPersistModel read(CmsNews cmsNews) {
        int line = baseMapper.readById(cmsNews);

        return new CyPersistModel(line);
    }


}
