package org.rcisoft.business.cmstask.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmstask.entity.CmsTask;
import org.rcisoft.business.cmstask.service.CmsTaskService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年6月11日 下午5:32:32.
 */
@RestController
@RequestMapping("/cmstask")
public class CmsTaskController extends CyPaginationController<CmsTask> {


    @Autowired
    private CmsTaskService cmsTaskServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:add')")
    @CyOpeLogAnno(title = "system-任务表管理-新增任务表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加任务表", notes = "添加任务表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsTask cmsTask, BindingResult bindingResult) {
        CyPersistModel data = cmsTaskServiceImpl.persist(cmsTask);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsTask);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:delete')")
    @CyOpeLogAnno(title = "system-任务表管理-删除任务表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除任务表", notes = "逻辑删除任务表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId, CmsTask cmsTask) {
        cmsTask.setBusinessId(businessId);
        CyPersistModel data = cmsTaskServiceImpl.removeLogical(cmsTask);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:delete')")
    @CyOpeLogAnno(title = "system-任务表管理-删除任务表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除任务表", notes = "删除任务表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable Integer businessId, CmsTask cmsTask) {
        cmsTask.setBusinessId(businessId);
        CyPersistModel data = cmsTaskServiceImpl.remove(cmsTask);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:update')")
    @CyOpeLogAnno(title = "system-任务表管理-修改任务表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改任务表", notes = "修改任务表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable Integer businessId, @Valid CmsTask cmsTask, BindingResult bindingResult) {
        cmsTask.setBusinessId(businessId);
        CyPersistModel data = cmsTaskServiceImpl.merge(cmsTask);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsTask);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:query')")
    @CyOpeLogAnno(title = "system-任务表管理-查询任务表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一任务表", notes = "查询单一任务表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsTaskServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:list')")
    @CyOpeLogAnno(title = "system-任务表管理-查询任务表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询任务表集合", notes = "查询任务表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(CmsTask cmsTask) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsTaskServiceImpl.findAll(cmsTask));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:task:list')")
    @CyOpeLogAnno(title = "system-任务表管理-查询任务表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询任务表集合", notes = "分页查询任务表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(CmsTask cmsTask) {
        cmsTaskServiceImpl.findAllByPagination(getPaginationUtility(), cmsTask);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-任务表管理-查询任务表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出任务表信息", notes = "导出任务表信息")
    @GetMapping(value = "/export")
    public void outCmsTask(HttpServletResponse response, CmsTask cmsTask, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "任务表信息.xls";
                break;
            case "1":
                excelName = "任务表信息.xlsx";
                break;
            case "2":
                excelName = "任务表信息.csv";
                break;
        }
        List<CmsTask> cmsTaskList = cmsTaskServiceImpl.export(cmsTask);
        CyEpExcelUtil.exportExcel(cmsTaskList, "任务表信息", "任务表信息", CmsTask.class, excelName, response);
    }
}
