package org.rcisoft.business.cmstask.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.cmstask.dao.CmsTaskRepository;
import org.rcisoft.business.cmstask.entity.CmsTask;
import org.rcisoft.business.cmstask.service.CmsTaskService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2024年6月11日 下午5:32:32.
 */
@Service
@Transactional(readOnly = true, propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class CmsTaskServiceImpl extends ServiceImpl<CmsTaskRepository, CmsTask> implements CmsTaskService {


    /**
     * 保存 任务表
     *
     * @param cmsTask
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(CmsTask cmsTask) {
        //增加操作
        int line = baseMapper.insert(cmsTask);
        log.debug(CyUserUtil.getAuthenUsername() + "新增了ID为" +
                cmsTask.getBusinessId() + "的任务表信息");
        return new CyPersistModel(line);
    }

    /**
     * 删除 任务表
     *
     * @param cmsTask
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(CmsTask cmsTask) {
        int line = baseMapper.realDelete(cmsTask);
        log.debug(CyUserUtil.getAuthenUsername() + "删除了ID为" +
                cmsTask.getBusinessId() + "的任务表信息");
        return new CyPersistModel(line);
    }

    /**
     * 逻辑删除 任务表
     *
     * @param cmsTask
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(CmsTask cmsTask) {
        cmsTask.setDeleted();
        int line = baseMapper.deleteById(cmsTask);
        log.debug(CyUserUtil.getAuthenUsername() + "逻辑删除了ID为" +
                cmsTask.getBusinessId() + "的任务表信息");
        return new CyPersistModel(line);
    }

    /**
     * 修改 任务表
     *
     * @param cmsTask
     * @return
     */
    @Transactional(propagation = Propagation.REQUIRED, isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(CmsTask cmsTask) {
        int line = baseMapper.updateById(cmsTask);
        log.debug(CyUserUtil.getAuthenUsername() + "修改了ID为" + cmsTask.getBusinessId() + "的任务表信息");
        return new CyPersistModel(line);
    }

    /**
     * 根据id查询 任务表
     *
     * @param id
     * @return
     */
    @Override
    public CmsTask findById(String id) {
        return baseMapper.selectById(id);
    }

    /**
     * 分页查询 任务表
     *
     * @param cmsTask
     * @return
     */
    @Override
    public IPage<CmsTask> findAllByPagination(CyPageInfo<CmsTask> paginationUtility,
                                              CmsTask cmsTask) {
        return baseMapper.queryCmsTasksPaged(paginationUtility, cmsTask);

    }

    /**
     * 查询list 任务表
     *
     * @param cmsTask
     * @return
     */
    @Override
    public List<CmsTask> findAll(CmsTask cmsTask) {
        return baseMapper.queryCmsTasks(cmsTask);

    }

    /**
     * 导出任务表
     *
     * @return
     */
    @Override
    public List<CmsTask> export(CmsTask cmsTask) {
        List<CmsTask> cmsTaskList = baseMapper.queryCmsTasks(cmsTask);
        return cmsTaskList;
    }

    /**
     * add 返回的Integer是当前数据的id
     */
    @Override
    public CmsTask add(String name) {
        //创建任务
        CmsTask cmsTask = new CmsTask();
        //1.主题
        cmsTask.setTopic(name);
        //类型
        cmsTask.setType("1");
        //爬取状态
        cmsTask.setStatus("0");
        cmsTask.setFlag("1");
        baseMapper.insert(cmsTask);
        return cmsTask;

    }

}
