package org.rcisoft.business.cmsvideo.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsnews.entity.CmsNews;
import org.rcisoft.business.cmsvideo.entity.CmsVideo;
import org.rcisoft.business.cmsvideo.service.CmsVideoService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年6月3日 下午3:35:01.
 */
@RestController
@RequestMapping("/cmsvideo")
public class CmsVideoController extends CyPaginationController<CmsVideo> {


    @Autowired
    private CmsVideoService cmsVideoServiceImpl;

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:add')")
    @CyOpeLogAnno(title = "system-视频表管理-新增视频表", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加视频表", notes = "添加视频表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid CmsVideo cmsVideo, BindingResult bindingResult) {
        CyPersistModel data = cmsVideoServiceImpl.persist(cmsVideo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:delete')")
    @CyOpeLogAnno(title = "system-视频表管理-删除视频表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除视频表", notes = "逻辑删除视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}/{unitId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId, @PathVariable String unitId, CmsVideo cmsVideo) {
        //判断unitId是否为字符串null
        if (!"null".equals(unitId)) {
            cmsVideo.setUnitId(unitId);
        }
        cmsVideo.setBusinessId(businessId);
        CyPersistModel data = cmsVideoServiceImpl.removeLogical(cmsVideo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:delete')")
    @CyOpeLogAnno(title = "system-视频表管理-删除视频表", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除视频表", notes = "删除视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, CmsVideo cmsVideo) {
        cmsVideo.setBusinessId(businessId);
        CyPersistModel data = cmsVideoServiceImpl.remove(cmsVideo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:update')")
    @CyOpeLogAnno(title = "system-视频表管理-修改视频表", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改视频表", notes = "修改视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid CmsVideo cmsVideo, BindingResult bindingResult) {
        cmsVideo.setBusinessId(businessId);
        CyPersistModel data = cmsVideoServiceImpl.merge(cmsVideo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideo);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:query')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一视频表", notes = "查询单一视频表")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideoServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:list')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询视频表集合", notes = "查询视频表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(CmsVideo cmsVideo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideoServiceImpl.findAll(cmsVideo));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:video:list')")
    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询视频表集合", notes = "分页查询视频表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(CmsVideo cmsVideo) {
        cmsVideoServiceImpl.findAllByPagination(getPaginationUtility(), cmsVideo);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-视频表管理-查询视频表", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出视频表信息", notes = "导出视频表信息")
    @GetMapping(value = "/export")
    public void outCmsVideo(HttpServletResponse response, CmsVideo cmsVideo, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "视频表信息.xls";
                break;
            case "1":
                excelName = "视频表信息.xlsx";
                break;
            case "2":
                excelName = "视频表信息.csv";
                break;
        }
        List<CmsVideo> cmsVideoList = cmsVideoServiceImpl.export(cmsVideo);
        CyEpExcelUtil.exportExcel(cmsVideoList, "视频表信息", "视频表信息", CmsVideo.class, excelName, response);
    }

    /**
     * 查询视频url地址
     */
    @ApiOperation(value = "查询视频url地址", notes = "查询视频url地址")
    @GetMapping(value = "/getVideoUrl")
    public CyResult getVideoUrl(CmsVideo cmsVideo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideoServiceImpl.getVideoUrl(cmsVideo));
    }


    /*------------------------------小程序---------------------------------------*/
    @ApiOperation(value = "小程序查询视频列表", notes = "小程序查询视频列表")
    @GetMapping(value = "/miniProgram/listByClassification")
    public CyResult listByClassification(CmsVideo cmsVideo) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideoServiceImpl.listByClassification(getPaginationUtility(), cmsVideo));
    }

    /**
     * 增加阅读量
     */
    @ApiOperation(value = "增加阅读量", notes = "增加阅读量")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/miniProgram/read/{businessId:\\w+}")
    public CyResult read(@PathVariable int businessId, @Valid CmsVideo cmsVideo, BindingResult bindingResult) {
        cmsVideo.setBusinessId(businessId);
        CyPersistModel data = cmsVideoServiceImpl.read(cmsVideo);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cmsVideo);
    }

}
