package org.rcisoft.business.crawler.service.impl;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.rcisoft.business.cmsnews.entity.CmsNews;
import org.rcisoft.business.cmsnews.service.CmsNewsService;
import org.rcisoft.business.crawler.api.WeiXinApi;
import org.rcisoft.business.crawler.model.Article;
import org.rcisoft.business.crawler.model.BizData;
import org.rcisoft.business.crawler.model.WxResultBody;
import org.rcisoft.business.crawler.okhttp.MyCookieStore;
import org.rcisoft.business.crawler.service.PublicAccountCrawlerService;
import org.rcisoft.business.crawler.utils.HttpUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.FutureTask;

/**
 * 公众号crawler服务
 *
 * @author gxk
 */
@Service
public class PublicAccountCrawlerServiceImpl implements PublicAccountCrawlerService {
    @Autowired
    WebsiteCrawlerServiceImpl websiteCrawlerServiceImpl;
    @Autowired
    private CmsNewsService cmsNewsService;


    /**
     * 根据公众号名查询其文章
     *
     * @param
     * @return
     */
    @Override
    public Integer scanImage(String publicAccountNames) throws Exception {
        // 轮询二维码状态接口
        FutureTask<Integer> futureTask = new FutureTask<>(new Callable<Integer>() {
            @Override
            public Integer call() throws Exception {
                while (true) {
                    WxResultBody askQRCode = WeiXinApi.askQRCode();
                    Integer status = askQRCode.getStatus();
                    if (status == 3) {
                        System.out.println("二维码已过期");
                        return 3;
                    } else if (status == 4) {
                        System.out.println("已扫码，等待确认");
                    } else if (status == 1) {
                        System.out.println("已确认登录，请稍后...");
                        return 1;
                    }
                    try {
                        Thread.sleep(1000);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
            }
        });

        while (true) {
            Thread queryThread = new Thread(futureTask);
            queryThread.start();
            if (!futureTask.isDone()) {
                System.out.println("--正在查询扫码状态，请尽快扫码！");
            }

            try {
                Integer integer = futureTask.get();
                if (integer == 1) {
                    //说明扫码确认成功，否则重新获取图片
                    break;
                } else {
                    break;
                }
            } catch (Exception e) {
                System.out.println("查询接口出错了");
                break;
            }
        }
        // 确认登录后，请求登录接口，拿到登录状态的cookie
        WxResultBody bizlogin = WeiXinApi.bizlogin();
        String redirect_url = bizlogin.getRedirect_url();
        Map<String, String> loginRes = HttpUtils.parseQueryParams(redirect_url);
        //得到token
        String token = loginRes.get("token");
        MyCookieStore.setToken(token);
        System.out.println("---恭喜你，登录成功！");
        //计数器
        int count = 0;

        for (String publicAccountName : Arrays.asList(publicAccountNames.split(","))) {// ok
            WxResultBody<List<BizData>> searchBiz = WeiXinApi.searchBiz(publicAccountName);
            List<BizData> list = searchBiz.getList();
            BizData select = null;
            if (list.size() > 0) {
                select = list.get(0);
                System.out.println(String.format("--好的，开始搜索【%s】的文章...", select.getNickname()));
                //字典控制爬取数量
                //查询字典  还要在别的地方用所以 字段传入不写死 第一个传入网站名称，第二个传入 控制的字典词  死值hōtori_num
                Integer dictionaryValue = cmsNewsService.selectDictionaryControl(publicAccountName, "hōtori_num");
                List<Article> articleList = WeiXinApi.getArticleList(dictionaryValue, select.getFakeid());
                for (Article article : articleList) {
                    if (cmsNewsService.getNewsByTitleByTitle(article.getTitle()) == null) {
                        System.out.println("---" + article.getTitle() + "-----" + article.getLink());
                        //通过link 转化 html
                        System.out.println(Jsoup.connect(article.getLink()).get());
                        Map<String, String> map = WebsiteCrawlerServiceImpl.getWeiXin(article, Jsoup.connect(article.getLink()).get());
                        // 图片转换
                        Document parse = Jsoup.parse(map.get("content"));
                        websiteCrawlerServiceImpl.replaceImgSrc(parse);
                        // html 转 markdown, 再转回来
                        String markdown = websiteCrawlerServiceImpl.convertHtmlToMarkdown(parse.html());
                        String content = websiteCrawlerServiceImpl.convertMarkdownToHtml(markdown);
                        CmsNews cmsNew = CmsNews.builder()
                                .releaseDate(new Date())
                                .title(map.get("title"))
                                .details(content)
                                .isRecommended(0)
                                .isTop(0)
                                .newsType("0").build();
                        cmsNew.setFlag("1");
                        // 插入文章
                        cmsNewsService.persist(cmsNew);
                        count++;
                    }
                }
            }
        }
        return count;
    }
}

