package org.rcisoft.business.sysunit.controller;


/*固定导入*/

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.rcisoft.business.cmsbannerunit.service.CmsBannerUnitService;
import org.rcisoft.business.cmspriceclick.service.CmsPriceClickService;
import org.rcisoft.business.cmsunitnewvideo.service.CmsUnitNewVideoService;
import org.rcisoft.business.sysunit.entity.SysUnit;
import org.rcisoft.business.sysunit.service.SysUnitService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.sys.rbac.user.entity.SysUserRbac;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import java.util.List;

/**
 * Created by cy on 2024年6月3日 下午3:35:01.
 */
@RestController
@RequestMapping("/sysunit")
public class SysUnitController extends CyPaginationController<SysUnit> {


    @Autowired
    private SysUnitService sysUnitServiceImpl;

    @Autowired
    private CmsBannerUnitService cmsBannerUnitService;

    @Autowired
    private CmsUnitNewVideoService cmsUnitNewVideoService;
    @Autowired
    private CmsPriceClickService cmsPriceClickService;

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:add')")
    @CyOpeLogAnno(title = "system-单位管理管理-新增单位管理", businessType = CyLogTypeEnum.INSERT)
    @ApiOperation(value = "添加单位管理", notes = "添加单位管理")
    @PostMapping(value = "/add")
    public CyResult add(@Valid SysUnit sysUnit, BindingResult bindingResult) {
        CyPersistModel data = sysUnitServiceImpl.persist(sysUnit);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnit);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:delete')")
    @CyOpeLogAnno(title = "system-单位管理管理-删除单位管理", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "逻辑删除单位管理", notes = "逻辑删除单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable Integer businessId, SysUnit sysUnit) {
        //判断当商家id不能为空
        if (businessId != null) {
            sysUnit.setBusinessId(businessId);
            //1.逻辑删除当前商家信息
            CyPersistModel data = sysUnitServiceImpl.removeLogical(sysUnit);
            //2.物理删除当前商家绑定的代言人信息
            sysUnitServiceImpl.deleteTheUserByMerchantId(sysUnit);
            //3.物理删除当前商家与banner绑定信息
            cmsBannerUnitService.deleteTheUserByMerchantId(sysUnit);
            //4.物理删除当前商家与文章视频分配中间表
            cmsUnitNewVideoService.deleteTheUserByMerchantId(sysUnit);
            //5.逻辑删除当前商家与文章视频点击量表
            cmsPriceClickService.updateTheUserByMerchantId(sysUnit);
            return CyResultGenUtil.builder(data,
                    CyMessCons.MESSAGE_ALERT_SUCCESS,
                    CyMessCons.MESSAGE_ALERT_ERROR,
                    businessId);
        }
        return null;
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:delete')")
    @CyOpeLogAnno(title = "system-单位管理管理-删除单位管理", businessType = CyLogTypeEnum.DELETE)
    @ApiOperation(value = "删除单位管理", notes = "删除单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId, SysUnit sysUnit) {
        sysUnit.setBusinessId(businessId);
        CyPersistModel data = sysUnitServiceImpl.remove(sysUnit);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                businessId);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:update')")
    @CyOpeLogAnno(title = "system-单位管理管理-修改单位管理", businessType = CyLogTypeEnum.UPDATE)
    @ApiOperation(value = "修改单位管理", notes = "修改单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid SysUnit sysUnit, BindingResult bindingResult) {
        sysUnit.setBusinessId(businessId);
        CyPersistModel data = sysUnitServiceImpl.merge(sysUnit);
        return CyResultGenUtil.builder(data,
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnit);
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:query')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单一单位管理", notes = "查询单一单位管理")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.findById(businessId));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:list')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单位管理集合", notes = "查询单位管理集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.findAll(sysUnit));
    }

    //@PreAuthorize("@cyPerm.hasPerm('sys:unit:list')")
    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "分页查询单位管理集合", notes = "分页查询单位管理集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(SysUnit sysUnit) {
        sysUnitServiceImpl.findAllByPagination(getPaginationUtility(), sysUnit);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.EXPORT)
    @ApiOperation(value = "导出单位管理信息", notes = "导出单位管理信息")
    @GetMapping(value = "/export")
    public void outSysUnit(HttpServletResponse response, SysUnit sysUnit, @PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName = "";
        switch (excelId) {
            case "0":
                excelName = "单位管理信息.xls";
                break;
            case "1":
                excelName = "单位管理信息.xlsx";
                break;
            case "2":
                excelName = "单位管理信息.csv";
                break;
        }
        List<SysUnit> sysUnitList = sysUnitServiceImpl.export(sysUnit);
        CyEpExcelUtil.exportExcel(sysUnitList, "单位管理信息", "单位管理信息", SysUnit.class, excelName, response);
    }

    @CyOpeLogAnno(title = "system-单位管理管理-查询单位管理", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询单位管理集合", notes = "查询单位管理集合")
    @GetMapping(value = "/querySysUsers")
    public CyResult querySysUsers(SysUserRbac sysUserRbac) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.listAllUser(sysUserRbac));
    }

    @CyOpeLogAnno(title = "system-单位管理管理-查询商家管理员信息", businessType = CyLogTypeEnum.QUERY)
    @ApiOperation(value = "查询商家管理员信息", notes = "查询商家管理员信息")
    @GetMapping(value = "/queryUnitAdmin")
    public CyResult queryUnitAdmin(SysUserRbac sysUserRbac) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.queryUnitAdmin(sysUserRbac));
    }







    /*--------------------------------------首页数据统计---------------------------------------*/

    /**
     * 代言人,文章，视频 统计
     */
    @ApiOperation(value = "首页数据统计", notes = "首页数据统计")
    @GetMapping(value = "/statistics")
    public CyResult statistics(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.statistics(sysUnit));
    }


    /**
     * 文章\视频 代言人推广次数 统计
     * 柱状图
     */
    @ApiOperation(value = "文章/视频 代言人推广次数 统计", notes = "文章/视频 代言人推广次数 统计")
    @GetMapping(value = "/statisticsByTypeBarChart")
    public CyResult statisticsByTypeBarChart(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.statisticsByTypeBarChart(sysUnit)
        );
    }

    /**
     * 文章 推广次数统计
     * 饼图 统计
     */
    @ApiOperation(value = "饼图 统计", notes = "饼图 统计")
    @GetMapping(value = "/statisticsByTypePieChart")
    public CyResult statisticsByTypePieChart(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.statisticsByTypePieChart(sysUnit)
        );
    }
    /**
     * 查询文章视频详情
     * */


    /**
     * 当前商家得推广金额排比
     */
    @ApiOperation(value = "当前商家得推广金额排比", notes = "当前商家得推广金额排比")
    @GetMapping(value = "/aListOfPromotionAmounts")
    public CyResult aListOfPromotionAmounts(SysUnit sysUnit) {
        //接口业务
        //1.通过获得得商家id 来一次性返回30条数据
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.aListOfPromotionAmounts(sysUnit));
    }


    /**
     * 文章/视频 推广次数
     */
    @ApiOperation(value = "文章/视频 推广次数", notes = "文章/视频 推广次数")
    @GetMapping(value = "/statisticsByType")
    public CyResult statisticsByType(SysUnit sysUnit) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.statisticsByType(sysUnit));
    }

    /*--------------------------------------小程序---------------------------------------*/

    /**
     * 当前登录人所属商家信息
     */
    @ApiOperation(value = "当前登录人所属商家信息", notes = "当前登录人所属商家信息")
    @GetMapping(value = "/getUnitInfo")
    public CyResult getUnitInfo(String wechatType) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                sysUnitServiceImpl.findUnitByUnit(wechatType));
    }


}
