package org.rcisoft.business.sysunitnews.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.business.sysunitnews.dao.SysUnitNewsRepository;
import org.rcisoft.business.sysunitnews.entity.SysUnitNews;
import org.rcisoft.business.sysunitnews.service.SysUnitNewsService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年6月3日 下午3:35:01.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class SysUnitNewsServiceImpl extends ServiceImpl<SysUnitNewsRepository,SysUnitNews>  implements SysUnitNewsService {


    /**
    * 保存 文章和单位中间表
    * @param sysUnitNews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(SysUnitNews sysUnitNews){
        //增加操作
        int line = baseMapper.insert(sysUnitNews);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            sysUnitNews.getBusinessId()+"的文章和单位中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 文章和单位中间表
    * @param sysUnitNews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(SysUnitNews sysUnitNews){
        int line = baseMapper.realDelete(sysUnitNews);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            sysUnitNews.getBusinessId()+"的文章和单位中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改 文章和单位中间表
    * @param sysUnitNews
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(SysUnitNews sysUnitNews){
        int line = baseMapper.updateById(sysUnitNews);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ sysUnitNews.getBusinessId()+"的文章和单位中间表信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 文章和单位中间表
    * @param id
    * @return
    */
    @Override
    public SysUnitNews findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 文章和单位中间表
    * @param sysUnitNews
    * @return
    */
    @Override
    public IPage<SysUnitNews> findAllByPagination(CyPageInfo<SysUnitNews> paginationUtility,
        SysUnitNews sysUnitNews){
        return baseMapper.querySysUnitNewssPaged(paginationUtility,sysUnitNews);

    }

    /**
    * 查询list 文章和单位中间表
    * @param sysUnitNews
    * @return
    */
    @Override
    public List<SysUnitNews> findAll(SysUnitNews sysUnitNews){
        return baseMapper.querySysUnitNewss(sysUnitNews);

    }

    /**
    * 导出文章和单位中间表
    * @return
    */
    @Override
    public List<SysUnitNews> export(SysUnitNews sysUnitNews) {
        List<SysUnitNews> sysUnitNewsList = baseMapper.querySysUnitNewss(sysUnitNews);
        return sysUnitNewsList;
    }

}
